from hermes_model import ModelInput, validate_entrypoint

from hm1d.model import HM1D


def run_hm1d(model_input: dict):
    """
    Entry Point for HERMES

    This method gets called by the HERMES framework. It is responsible for
    initializing the model and running the model with the given input.
    """

    model_input = ModelInput(**model_input)

    model = HM1D(model_input)

    model.fit()

    results = model.predict()

    results = model.parse_results(results)

    return results


@validate_entrypoint(induced=True)
def run_hm1d_validated(model_input: ModelInput):
    """
    Entry Point for HERMES

    This method gets called by the HERMES framework. It is responsible for
    initializing the model and running the model with the given input.
    """

    model = HM1D(model_input)

    model.fit()

    results = model.predict()

    results = model.parse_results(results)

    return results
